==> portmanager-0.2.9.tar.gz: portmanager-0.2.9/libMG/src/MGrFileTime.c <==
/************************************************************************/
/*	Copyright (C) 2004  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/
#include	<libMG.h>

unsigned long int MGrFileTime( char* fileName )
{
	char			id[]		= "MGrFileSize";
	unsigned long int	fileTime	= 0;
	signed	int		errorCode	= 0;
	struct	stat		status;

	errorCode	= stat( fileName, &status);
	if( errorCode == -1 )
	{
		fprintf( stderr, "%s error:  stat of %s returned an error\n", id, fileName );
		perror( "system message" );
		return( 0 );
	}
	fileTime	= status.st_mtime;
	return( fileTime );
}

==> portmanager-0.3.4.tar.gz: portmanager-0.3.4/libMG/src/MGrFileTime.c <==
/************************************************************************/
/*	Copyright (C) 2004  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/
#include	<libMG.h>

unsigned long int MGrFileTime( char* fileName )
{
	char			id[]		= "MGrFileTime";
	unsigned long int	fileTime	= 0;
	signed	int		errorCode	= 0;
	struct	stat		status;

	errorCode	= stat( fileName, &status);
	if( errorCode == -1 )
	{
/*
		fprintf( stderr, "%s error:  stat of %s returned an error\n", id, fileName );
		perror( "system message" );
*/
		return( 0 );
	}
	fileTime	= status.st_mtime;
	return( fileTime );
}
